# Uptrace for Python

![build workflow](https://github.com/uptrace/uptrace-python/actions/workflows/build.yml/badge.svg)
[![Documentation](https://img.shields.io/badge/uptrace-documentation-informational)](https://uptrace.dev/get/opentelemetry-python.html)
[![Chat](https://img.shields.io/badge/-telegram-red?color=white&logo=telegram&logoColor=black)](https://t.me/uptrace)

<a href="https://uptrace.dev/get/opentelemetry-python.html">
  <img src="https://uptrace.dev/get/devicon/python-original.svg" height="200px" />
</a>

## Introduction

uptrace-python is a thin wrapper over
[opentelemetry-python](https://github.com/open-telemetry/opentelemetry-python) that exports
[traces](https://uptrace.dev/opentelemetry/distributed-tracing.html),
[metrics](https://uptrace.dev/opentelemetry/metrics.html), and logs to Uptrace.

- [Documentation](https://uptrace.dev/get/opentelemetry-python.html)
- [Examples](example)
- [OpenTelemetry Python instrumentations](https://uptrace.dev/opentelemetry/instrumentations/?lang=python)
- [OpenTelemetry Django](https://uptrace.dev/opentelemetry/instrumentations/python-django.html)
- [OpenTelemetry Flask](https://uptrace.dev/opentelemetry/instrumentations/python-flask.html)
- [OpenTelemetry FastAPI](https://uptrace.dev/opentelemetry/instrumentations/python-fastapi.html)
- [OpenTelemetry SQLAlchemy](https://uptrace.dev/opentelemetry/instrumentations/python-sqlalchemy.html)
